"""
A collection of tools and EOTasks for image co-registration
"""

from .coregistration import RegistrationTask, InterpolationType, ECCRegistration, PointBasedRegistration, \
    ThunderRegistration

__version__ = '0.6.0'
